
From: Thomas Gleixner <tglx@linutronix.de>

Convert the initializers of hw_interrupt_type structures to C99 initializers.

Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc/syslib/cpc700_pic.c |   12 ++++--------
 arch/ppc/syslib/i8259.c      |   13 +++++--------
 arch/ppc/syslib/open_pic2.c  |   12 +++++-------
 arch/ppc/syslib/ppc403_pic.c |   11 ++++-------
 arch/ppc/syslib/xilinx_pic.c |   13 +++++--------
 5 files changed, 23 insertions(+), 38 deletions(-)

diff -puN arch/ppc/syslib/cpc700_pic.c~ppc-c99-initializers-for-hw_interrupt_type-structures arch/ppc/syslib/cpc700_pic.c
--- devel/arch/ppc/syslib/cpc700_pic.c~ppc-c99-initializers-for-hw_interrupt_type-structures	2005-07-27 13:53:32.000000000 -0700
+++ devel-akpm/arch/ppc/syslib/cpc700_pic.c	2005-07-27 13:53:32.000000000 -0700
@@ -90,14 +90,10 @@ cpc700_mask_and_ack_irq(unsigned int irq
 }
 
 static struct hw_interrupt_type cpc700_pic = {
-	"CPC700 PIC",
-	NULL,
-	NULL,
-	cpc700_unmask_irq,
-	cpc700_mask_irq,
-	cpc700_mask_and_ack_irq,
-	NULL,
-	NULL
+	.typename = "CPC700 PIC",
+	.enable = cpc700_unmask_irq,
+	.disable = cpc700_mask_irq,
+	.ack = cpc700_mask_and_ack_irq,
 };
 
 __init static void
diff -puN arch/ppc/syslib/i8259.c~ppc-c99-initializers-for-hw_interrupt_type-structures arch/ppc/syslib/i8259.c
--- devel/arch/ppc/syslib/i8259.c~ppc-c99-initializers-for-hw_interrupt_type-structures	2005-07-27 13:53:32.000000000 -0700
+++ devel-akpm/arch/ppc/syslib/i8259.c	2005-07-27 13:53:32.000000000 -0700
@@ -129,14 +129,11 @@ static void i8259_end_irq(unsigned int i
 }
 
 struct hw_interrupt_type i8259_pic = {
-	" i8259    ",
-	NULL,
-	NULL,
-	i8259_unmask_irq,
-	i8259_mask_irq,
-	i8259_mask_and_ack_irq,
-	i8259_end_irq,
-	NULL
+	.typename = " i8259    ",
+	.enable = i8259_unmask_irq,
+	.disable = i8259_mask_irq,
+	.ack = i8259_mask_and_ack_irq,
+	.end = i8259_end_irq,
 };
 
 static struct resource pic1_iores = {
diff -puN arch/ppc/syslib/open_pic2.c~ppc-c99-initializers-for-hw_interrupt_type-structures arch/ppc/syslib/open_pic2.c
--- devel/arch/ppc/syslib/open_pic2.c~ppc-c99-initializers-for-hw_interrupt_type-structures	2005-07-27 13:53:32.000000000 -0700
+++ devel-akpm/arch/ppc/syslib/open_pic2.c	2005-07-27 13:53:32.000000000 -0700
@@ -82,13 +82,11 @@ static void openpic2_end_irq(unsigned in
 static void openpic2_ack_irq(unsigned int irq_nr);
 
 struct hw_interrupt_type open_pic2 = {
-	" OpenPIC2 ",
-	NULL,
-	NULL,
-	openpic2_enable_irq,
-	openpic2_disable_irq,
-	openpic2_ack_irq,
-	openpic2_end_irq,
+	.typename = " OpenPIC2 ",
+	.enable = openpic2_enable_irq,
+	.disable = openpic2_disable_irq,
+	.ack = openpic2_ack_irq,
+	.end = openpic2_end_irq,
 };
 
 /*
diff -puN arch/ppc/syslib/ppc403_pic.c~ppc-c99-initializers-for-hw_interrupt_type-structures arch/ppc/syslib/ppc403_pic.c
--- devel/arch/ppc/syslib/ppc403_pic.c~ppc-c99-initializers-for-hw_interrupt_type-structures	2005-07-27 13:53:32.000000000 -0700
+++ devel-akpm/arch/ppc/syslib/ppc403_pic.c	2005-07-27 13:53:32.000000000 -0700
@@ -34,13 +34,10 @@ static void ppc403_aic_disable(unsigned 
 static void ppc403_aic_disable_and_ack(unsigned int irq);
 
 static struct hw_interrupt_type ppc403_aic = {
-	"403GC AIC",
-	NULL,
-	NULL,
-	ppc403_aic_enable,
-	ppc403_aic_disable,
-	ppc403_aic_disable_and_ack,
-	0
+	.typename = "403GC AIC",
+	.enable = ppc403_aic_enable,
+	.disable = ppc403_aic_disable,
+	.ack = ppc403_aic_disable_and_ack,
 };
 
 int
diff -puN arch/ppc/syslib/xilinx_pic.c~ppc-c99-initializers-for-hw_interrupt_type-structures arch/ppc/syslib/xilinx_pic.c
--- devel/arch/ppc/syslib/xilinx_pic.c~ppc-c99-initializers-for-hw_interrupt_type-structures	2005-07-27 13:53:32.000000000 -0700
+++ devel-akpm/arch/ppc/syslib/xilinx_pic.c	2005-07-27 13:53:32.000000000 -0700
@@ -79,14 +79,11 @@ xilinx_intc_end(unsigned int irq)
 }
 
 static struct hw_interrupt_type xilinx_intc = {
-	"Xilinx Interrupt Controller",
-	NULL,
-	NULL,
-	xilinx_intc_enable,
-	xilinx_intc_disable,
-	xilinx_intc_disable_and_ack,
-	xilinx_intc_end,
-	0
+	.typename = "Xilinx Interrupt Controller",
+	.enable = xilinx_intc_enable,
+	.disable = xilinx_intc_disable,
+	.ack = xilinx_intc_disable_and_ack,
+	.end = xilinx_intc_end,
 };
 
 int
_
